@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import asyncio
 from cachetools import keys, Cache
 from functools import wraps, partial, update_wrapper
@@ -9,7 +11,6 @@ __all__ = (
     "iscorofunc",
     "get_decorator",
     "somecachedmethod",
-    "classcache"
 )
 
 
